/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_gd extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "ADP", "ADP" },
            { "AED", "AED" },
            { "AFA", "AFA" },
            { "AFN", "AFN" },
            { "ALK", "ALK" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "AOK", "AOK" },
            { "AON", "AON" },
            { "AOR", "AOR" },
            { "ARA", "ARA" },
            { "ARL", "ARL" },
            { "ARM", "ARM" },
            { "ARP", "ARP" },
            { "ARS", "ARS" },
            { "ATS", "ATS" },
            { "AWG", "AWG" },
            { "AZM", "AZM" },
            { "AZN", "AZN" },
            { "BAD", "BAD" },
            { "BAM", "BAM" },
            { "BAN", "BAN" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BEC", "BEC" },
            { "BEF", "BEF" },
            { "BEL", "BEL" },
            { "BGL", "BGL" },
            { "BGM", "BGM" },
            { "BGN", "BGN" },
            { "BGO", "BGO" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BOL", "BOL" },
            { "BOP", "BOP" },
            { "BOV", "BOV" },
            { "BRB", "BRB" },
            { "BRC", "BRC" },
            { "BRE", "BRE" },
            { "BRN", "BRN" },
            { "BRR", "BRR" },
            { "BRZ", "BRZ" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BUK", "BUK" },
            { "BWP", "BWP" },
            { "BYB", "BYB" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHE", "CHE" },
            { "CHF", "CHF" },
            { "CHW", "CHW" },
            { "CLE", "CLE" },
            { "CLF", "CLF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "CNX", "CNX" },
            { "COP", "COP" },
            { "COU", "COU" },
            { "CRC", "CRC" },
            { "CSD", "CSD" },
            { "CSK", "CSK" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CYP", "CYP" },
            { "CZK", "CZK" },
            { "DDM", "DDM" },
            { "DEM", "DEM" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "ECS", "ECS" },
            { "ECV", "ECV" },
            { "EEK", "EEK" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ESA", "ESA" },
            { "ESB", "ESB" },
            { "ESP", "ESP" },
            { "ETB", "ETB" },
            { "FIM", "FIM" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "FRF", "FRF" },
            { "GEK", "GEK" },
            { "GEL", "GEL" },
            { "GHC", "GHC" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GNS", "GNS" },
            { "GQE", "GQE" },
            { "GRD", "GRD" },
            { "GTQ", "GTQ" },
            { "GWE", "GWE" },
            { "GWP", "GWP" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRD", "HRD" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IEP", "IEP" },
            { "ILP", "ILP" },
            { "ILR", "ILR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISJ", "ISJ" },
            { "ISK", "ISK" },
            { "ITL", "ITL" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KRH", "KRH" },
            { "KRO", "KRO" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LSL", "LSL" },
            { "LTL", "LTL" },
            { "LTT", "LTT" },
            { "LUC", "LUC" },
            { "LUF", "LUF" },
            { "LUL", "LUL" },
            { "LVL", "LVL" },
            { "LVR", "LVR" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MAF", "MAF" },
            { "MCF", "MCF" },
            { "MDC", "MDC" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MGF", "MGF" },
            { "MKD", "MKD" },
            { "MKN", "MKN" },
            { "MLF", "MLF" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MTL", "MTL" },
            { "MTP", "MTP" },
            { "MUR", "MUR" },
            { "MVP", "MVP" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXP", "MXP" },
            { "MXV", "MXV" },
            { "MYR", "MYR" },
            { "MZE", "MZE" },
            { "MZM", "MZM" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIC", "NIC" },
            { "NIO", "NIO" },
            { "NLG", "NLG" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEI", "PEI" },
            { "PEN", "PEN" },
            { "PES", "PES" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PLZ", "PLZ" },
            { "PTE", "PTE" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RHD", "RHD" },
            { "ROL", "ROL" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RUR", "RUR" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDD", "SDD" },
            { "SDG", "SDG" },
            { "SDP", "SDP" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SIT", "SIT" },
            { "SKK", "SKK" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SRG", "SRG" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SUR", "SUR" },
            { "SVC", "SVC" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJR", "TJR" },
            { "TJS", "TJS" },
            { "TMM", "TMM" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TPE", "TPE" },
            { "TRL", "TRL" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UAK", "UAK" },
            { "UGS", "UGS" },
            { "UGX", "UGX" },
            { "USD", "$" },
            { "USN", "USN" },
            { "USS", "USS" },
            { "UYI", "UYI" },
            { "UYP", "UYP" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEB", "VEB" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VNN", "VNN" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "XAG", "XAG" },
            { "XAU", "XAU" },
            { "XBA", "XBA" },
            { "XBB", "XBB" },
            { "XBC", "XBC" },
            { "XBD", "XBD" },
            { "XDR", "XDR" },
            { "XEU", "XEU" },
            { "XFO", "XFO" },
            { "XFU", "XFU" },
            { "XPD", "XPD" },
            { "XPT", "XPT" },
            { "XRE", "XRE" },
            { "XSU", "XSU" },
            { "XTS", "XTS" },
            { "XUA", "XUA" },
            { "XXX", "XXX" },
            { "YDD", "YDD" },
            { "YER", "YER" },
            { "YUD", "YUD" },
            { "YUM", "YUM" },
            { "YUN", "YUN" },
            { "YUR", "YUR" },
            { "ZAL", "ZAL" },
            { "ZAR", "ZAR" },
            { "ZMK", "ZMK" },
            { "ZMW", "ZMW" },
            { "ZRN", "ZRN" },
            { "ZRZ", "ZRZ" },
            { "ZWD", "ZWD" },
            { "ZWL", "ZWL" },
            { "ZWR", "ZWR" },
            { "adp", "Peseta Andorrach" },
            { "aed", "Dirham nan Iomaratan Arabach Aonaichte" },
            { "afa", "Afghani Afghanach (1927\u20132002)" },
            { "afn", "Afghani Afghanach" },
            { "alk", "Lek Alb\u00e0ineach (1946\u20131965)" },
            { "all", "Lek Alb\u00e0ineach" },
            { "amd", "Dram Airmeineach" },
            { "ang", "Gulden Eileanan Aintilia nan T\u00ecrean \u00ccsle" },
            { "aoa", "Kwanza Ang\u00f2lach" },
            { "aok", "Kwanza Ang\u00f2lach (1977\u20131991)" },
            { "aon", "Kwanza \u00f9r Ang\u00f2lach (1990\u20132000)" },
            { "aor", "Kwanza ath-ghleusaichte Ang\u00f2lach (1995\u20131999)" },
            { "ara", "Austral Argantaineach" },
            { "arl", "Peso ley Argantaineach (1970\u20131983)" },
            { "arm", "Peso Argantaineach (1881\u20131970)" },
            { "arp", "Peso Argantaineach (1983\u20131985)" },
            { "ars", "Peso Argantaineach" },
            { "ats", "Schilling Ostaireach" },
            { "aud", "Dolar Astr\u00e0ilianach" },
            { "awg", "Florin Ar\u00f9bach" },
            { "azm", "Manat Asarbaide\u00e0nach (1993\u20132006)" },
            { "azn", "Manat Asarbaide\u00e0nach" },
            { "bad", "Dinar Bhosna agus Hearsagobhana (1992\u20131994)" },
            { "bam", "Mark iompachail Bhosna agus Hearsagobhana" },
            { "ban", "Dinar \u00f9r Bhosna agus Hearsagobhana (1994\u20131997)" },
            { "bbd", "Dolar Barbadach" },
            { "bdt", "Taka Bangladaiseach" },
            { "bec", "Franc Beilgeach (iompachail)" },
            { "bef", "Franc Beilgeach" },
            { "bel", "Franc Beilgeach (ionmhasail)" },
            { "bgl", "Lev cruaidh Bulgarach" },
            { "bgm", "Lev s\u00f2isealach Bulgarach" },
            { "bgn", "Lev Bulgarach" },
            { "bgo", "Lev Bulgarach (1879\u20131952)" },
            { "bhd", "Dinar Bachraineach" },
            { "bif", "Franc Burundaidheach" },
            { "bmd", "Dolar Bearm\u00f9dach" },
            { "bnd", "Dolar Br\u00f9naigheach" },
            { "bob", "Boliviano Boilibhiach" },
            { "bol", "Boliviano Boilibhiach (1863\u20131963)" },
            { "bop", "Peso Boilibhiach" },
            { "bov", "Mvdol Boilibhiach" },
            { "brb", "Cruzeiro \u00f9r Braisileach (1967\u20131986)" },
            { "brc", "Cruzado Braisileach (1986\u20131989)" },
            { "bre", "Cruzeiro Braisileach (1990\u20131993)" },
            { "brl", "Real Braisileach" },
            { "brn", "Cruzado \u00f9r Braisileach (1989\u20131990)" },
            { "brr", "Cruzeiro Braisileach (1993\u20131994)" },
            { "brz", "Cruzeiro Braisileach (1942\u20131967)" },
            { "bsd", "Dolar Bathamach" },
            { "btn", "Ngultrum But\u00e0nach" },
            { "buk", "Kyat Burmach" },
            { "bwp", "Pula Botsuanach" },
            { "byb", "R\u00f9bal \u00f9r Bealaruiseach (1994\u20131999)" },
            { "byn", "R\u00f9bal Bealaruiseach" },
            { "byr", "R\u00f9bal Bealaruiseach (2000\u20132016)" },
            { "bzd", "Dolar Beil\u00ecseach" },
            { "cad", "Dolar Canadach" },
            { "cdf", "Franc Congothach" },
            { "che", "E\u00f2ro WIR" },
            { "chf", "Franc Eilbheiseach" },
            { "chw", "Franc WIR" },
            { "cle", "Escudo Sileach" },
            { "clf", "Aonad cunntasachd Sileach (UF)" },
            { "clp", "Peso Sileach" },
            { "cnh", "Yuan S\u00ecneach (far-th\u00ecreach)" },
            { "cnx", "Dolar an t-sluagh-bhanca Sh\u00ecnich" },
            { "cny", "Yuan S\u00ecneach" },
            { "cop", "Peso Coloimbeach" },
            { "cou", "Aonad f\u00ecor-luach Coloimbeach" },
            { "crc", "Col\u00f3n Costa R\u00ecceach" },
            { "csd", "Dinar S\u00e8irbeach (2002\u20132006)" },
            { "csk", "Koruna cruaidh Seic-Sl\u00f2bhacach" },
            { "cuc", "Peso iompachail C\u00f9bach" },
            { "cup", "Peso C\u00f9bach" },
            { "cve", "Escudo a\u2019 Chip Uaine" },
            { "cyp", "Punnd C\u00ecoprasach" },
            { "czk", "Koruna Seiceach" },
            { "ddm", "Mark na Gearmailte an Ear" },
            { "dem", "Mark Gearmailteach" },
            { "djf", "Franc Diob\u00f9taidheach" },
            { "dkk", "Krone Danmhairgeach" },
            { "dop", "Peso Doiminiceach" },
            { "dzd", "Dinar Aildireach" },
            { "ecs", "Sucre Eacuadorach" },
            { "ecv", "Aonad luach chunbhalaich Eacuadorach" },
            { "eek", "Kroon Eastoineach" },
            { "egp", "Punnd \u00c8ipheiteach" },
            { "ern", "Nakfa Eartrach" },
            { "esa", "Peseta Sp\u00e0innteach (cunntas A)" },
            { "esb", "Peseta Sp\u00e0innteach (cunntas iompachail)" },
            { "esp", "Peseta Sp\u00e0innteach" },
            { "etb", "Birr Itiopach" },
            { "eur", "E\u00f2ro" },
            { "fim", "Markka Fionnlannach" },
            { "fjd", "Dolar F\u00ecditheach" },
            { "fkp", "Punnd F\u00e0clannach" },
            { "frf", "Franc Frangach" },
            { "gbp", "Punnd Sasannach" },
            { "gek", "Kupon larit Cairtbheileach" },
            { "gel", "Lari Cairtbheileach" },
            { "ghc", "Cedi G\u00e0nach (1979\u20132007)" },
            { "ghs", "Cedi G\u00e0nach" },
            { "gip", "Punnd Diobraltarach" },
            { "gmd", "Dalasi Gaimbitheach" },
            { "gnf", "Franc Ginitheach" },
            { "gns", "Syli Ginitheach" },
            { "gqe", "Ekwele Gini Meadhan-Chriosaich" },
            { "grd", "Drachma Greugach" },
            { "gtq", "Quetzal Guatamalach" },
            { "gwe", "Escudo Gini na Portagaile" },
            { "gwp", "Peso Gini-Biosothach" },
            { "gyd", "Dolar Guidhe\u00e0nach" },
            { "hkd", "Dolar Hong Kong" },
            { "hnl", "Lempira Hond\u00f9rach" },
            { "hrd", "Dinar Cr\u00f2thaiseach" },
            { "hrk", "Kuna Cr\u00f2thaiseach" },
            { "htg", "Gourde Haidhteach" },
            { "huf", "Forint Ungaireach" },
            { "idr", "Rupiah Innd-Innseach" },
            { "iep", "Punnd \u00c8ireannach" },
            { "ilp", "Punnd Iosraeleach" },
            { "ilr", "Sheqel Iosraeleach (1980\u20131985)" },
            { "ils", "Sheqel \u00f9r Iosraeleach" },
            { "inr", "Rupee Innseanach" },
            { "iqd", "Dinar Ior\u00e0cach" },
            { "irr", "Rial Ior\u00e0nach" },
            { "isj", "Kr\u00f3na Innis T\u00ecleach (1918\u20131981)" },
            { "isk", "Kr\u00f3na Innis T\u00ecleach" },
            { "itl", "Lira Eadailteach" },
            { "jmd", "Dolar Diameugach" },
            { "jod", "Dinar I\u00f2rdanach" },
            { "jpy", "Yen Seapanach" },
            { "kes", "Shilling Ceineach" },
            { "kgs", "Som C\u00ecorgasach" },
            { "khr", "Riel Cambuideach" },
            { "kmf", "Franc Comorosach" },
            { "kpw", "Won Choir\u00e8a a Tuath" },
            { "krh", "Hwan Choir\u00e8a a Deas (1953\u20131962)" },
            { "kro", "Won Choir\u00e8a a Deas (1945\u20131953)" },
            { "krw", "Won Choir\u00e8a a Deas" },
            { "kwd", "Dinar Cuibh\u00e8iteach" },
            { "kyd", "Dolar Caimeanach" },
            { "kzt", "Tenge Casachach" },
            { "lak", "Kip L\u00e0thosach" },
            { "lbp", "Punnd Leabanach" },
            { "lkr", "Rupee Sri Lancach" },
            { "lrd", "Dolar Lib\u00e8ireach" },
            { "lsl", "Loti Leasotach" },
            { "ltl", "Litas Liotuaineach" },
            { "ltt", "Talonas Liotuaineach" },
            { "luc", "Franc iompachail Lugsamburgach" },
            { "luf", "Franc Lugsamburgach" },
            { "lul", "Franc ionmhasail Lugsamburgach" },
            { "lvl", "Lats Laitbheach" },
            { "lvr", "R\u00f9bal Laitbheach" },
            { "lyd", "Dinar Libitheach" },
            { "mad", "Dirham Morocach" },
            { "maf", "Franc Morocach" },
            { "mcf", "Franc Monacach" },
            { "mdc", "Cupon Moldobhach" },
            { "mdl", "Leu Moldobhach" },
            { "mga", "Ariary Madagasgarach" },
            { "mgf", "Franc Madagasgarach" },
            { "mkd", "Denar Masadonach" },
            { "mkn", "Denar Masadonach (1992\u20131993)" },
            { "mlf", "Franc M\u00e0ilitheach" },
            { "mmk", "Kyat Mi\u00e0nmarach" },
            { "mnt", "Tugrik Mongolach" },
            { "mop", "Pataca Mac\u00e0thuach" },
            { "mro", "Ouguiya Morat\u00e0ineach (1973\u20132017)" },
            { "mru", "Ouguiya Morat\u00e0ineach" },
            { "mtl", "Lira Maltach" },
            { "mtp", "Punnd Maltach" },
            { "mur", "Rupee Moiriseasach" },
            { "mvp", "Rupee Maladaibheach" },
            { "mvr", "Rufiyaa Maladaibheach" },
            { "mwk", "Kwacha Malabhaidheach" },
            { "mxn", "Peso Meagsagach" },
            { "mxp", "Peso airgid Meagsagach (1861\u20131992)" },
            { "mxv", "Aonad inbheistidh Meagsagach" },
            { "myr", "Ringgit Malaidheach" },
            { "mze", "Escudo M\u00f2saimbiceach" },
            { "mzm", "Metical M\u00f2saimbiceach (1980\u20132006)" },
            { "mzn", "Metical M\u00f2saimbiceach" },
            { "nad", "Dolar Naimibitheach" },
            { "ngn", "Naira Nig\u00e8iriach" },
            { "nic", "C\u00f3rdoba Niocaragach (1988\u20131991)" },
            { "nio", "C\u00f3rdoba Niocaragach" },
            { "nlg", "Gulden Duitseach" },
            { "nok", "Krone Nirribheach" },
            { "npr", "Rupee Neap\u00e0lach" },
            { "nzd", "Dolar Shealainn Nuaidh" },
            { "omr", "Rial Om\u00e0nach" },
            { "pab", "Balboa Panamach" },
            { "pei", "Inti Pear\u00f9thach" },
            { "pen", "Sol Pear\u00f9thach" },
            { "pes", "Sol Pear\u00f9thach (1863\u20131965)" },
            { "pgk", "Kina Ghini Nuaidh Paputhaiche" },
            { "php", "Peso Filipineach" },
            { "pkr", "Rupee Pagast\u00e0nach" },
            { "pln", "Z\u0142oty P\u00f2lainneach" },
            { "plz", "Z\u0142oty P\u00f2lainneach (1950\u20131995)" },
            { "pte", "Escudo Portagaileach" },
            { "pyg", "Guaran\u00ed Paraguaidheach" },
            { "qar", "Rial Catarach" },
            { "rhd", "Dolar Rhodesiach" },
            { "rol", "Leu Rom\u00e0ineach (1952\u20132006)" },
            { "ron", "Leu Rom\u00e0ineach" },
            { "rsd", "Dinar S\u00e8irbeach" },
            { "rub", "R\u00f9bal Ruiseach" },
            { "rur", "R\u00f9bal Ruiseach (1991\u20131998)" },
            { "rwf", "Franc Rubhandach" },
            { "sar", "Riyal Sabhdach" },
            { "sbd", "Dolar Eileanan Sholaimh" },
            { "scr", "Rupee Seiseallach" },
            { "sdd", "Dinar Sud\u00e0nach (1992\u20132007)" },
            { "sdg", "Punnd Sud\u00e0nach" },
            { "sdp", "Punnd Sud\u00e0nach (1957\u20131998)" },
            { "sek", "Krona Suaineach" },
            { "sgd", "Dolar Singeap\u00f2rach" },
            { "shp", "Punnd Eilean Naomh Eilidh" },
            { "sit", "Tolar Sl\u00f2bhaineach" },
            { "skk", "Koruna Sl\u00f2bhacach" },
            { "sll", "Leone Siarra Le\u00f2mhannach" },
            { "sos", "Shilling Som\u00e0ilitheach" },
            { "srd", "Dolar Suranamach" },
            { "srg", "Gulden Suranamach" },
            { "ssp", "Punnd Sud\u00e0in a Deas" },
            { "std", "Dobra S\u00e3o Tom\u00e9 agus Pr\u00edncipe (1977\u20132017)" },
            { "stn", "Dobra S\u00e3o Tom\u00e9 agus Pr\u00edncipe" },
            { "sur", "R\u00f9bal Sovietach" },
            { "svc", "Col\u00f3n Salbhadorach" },
            { "syp", "Punnd Siridheach" },
            { "szl", "Lilangeni Suasaidheach" },
            { "thb", "Baht T\u00e0idheach" },
            { "tjr", "R\u00f9bal Taidigeach" },
            { "tjs", "Somoni Taidigeach" },
            { "tmm", "Manat Turcmanach (1993\u20132009)" },
            { "tmt", "Manat Turcmanach" },
            { "tnd", "Dinar Tuiniseach" },
            { "top", "Pa\u02bbanga Tongach" },
            { "tpe", "Escudo T\u00ecomorach" },
            { "trl", "Lira Turcach (1922\u20132005)" },
            { "try", "Lira Turcach" },
            { "ttd", "Dolar Thrianaid agus Thobago" },
            { "twd", "Dolar \u00f9r Taidh-Bh\u00e0nach" },
            { "tzs", "Shilling Tansanaidheach" },
            { "uah", "Hryvnia Ucr\u00e0ineach" },
            { "uak", "Karbovanets Ucr\u00e0ineach" },
            { "ugs", "Shilling Ugandach (1966\u20131987)" },
            { "ugx", "Shilling Ugandach" },
            { "usd", "Dolar nan St\u00e0itean Aonaichte" },
            { "usn", "Dolar nan SA (an ath\u2013latha)" },
            { "uss", "Dolar nan SA (an aon latha)" },
            { "uyi", "Peso Uruguaidheach (aonadan inneacsaichte)" },
            { "uyp", "Peso Uruguaidheach (1975\u20131993)" },
            { "uyu", "Peso Uruguaidheach" },
            { "uyw", "aonad inneacs tuarastail ainmeach Uruguaidh" },
            { "uzs", "Som Usbagach" },
            { "veb", "Bol\u00edvar Bheinisealach (1871\u20132008)" },
            { "vef", "Bol\u00edvar Bheinisealach (2008\u20132018)" },
            { "ves", "Bol\u00edvar Bheinisealach" },
            { "vnd", "Dong Bhiet-Namach" },
            { "vnn", "Dong Bhiet-Namach (1978\u20131985)" },
            { "vuv", "Vatu Vanuatuthach" },
            { "wst", "Tala Samothach" },
            { "xaf", "Franc CFA Meadhan-Afragach" },
            { "xag", "Airgead" },
            { "xau", "\u00d2r" },
            { "xba", "Aonad co-dh\u00e8anta E\u00f2rpach" },
            { "xbb", "Aonad airgid E\u00f2rpach" },
            { "xbc", "Aonad cunntasachd E\u00f2rpach (XBC)" },
            { "xbd", "Aonad cunntasachd E\u00f2rpach (XBD)" },
            { "xcd", "Dolar Caraibeach earach" },
            { "xdr", "C\u00f2ir tarraing sh\u00f2nraichte" },
            { "xeu", "Aonad airgeadra E\u00f2rpach" },
            { "xfo", "Franc \u00f2ir Frangach" },
            { "xfu", "Franc UIC Frangach" },
            { "xof", "Franc CFA Afraga an Iar" },
            { "xpd", "Pallaideam" },
            { "xpf", "Franc CFP" },
            { "xpt", "Platanam" },
            { "xre", "Aonad maoine RINET" },
            { "xsu", "Sucre" },
            { "xts", "C\u00f2d airgeadra fo dheuchainn" },
            { "xua", "Aonad cunntasachd ADB" },
            { "xxx", "Airgeadra neo-aithnichte" },
            { "ydd", "Dinar Eamanach" },
            { "yer", "Rial Eamanach" },
            { "yud", "Dinar cruaidh I\u00f9goslabhach (1966\u20131990)" },
            { "yum", "Dinar \u00f9r I\u00f9goslabhach (1994\u20132002)" },
            { "yun", "Dinar iompachail I\u00f9goslabhach (1990\u20131992)" },
            { "yur", "Dinar ath-leasaichte I\u00f9goslabhach (1992\u20131993)" },
            { "zal", "Rand Afraga a Deas (ionmhasail)" },
            { "zar", "Rand Afraga a Deas" },
            { "zmk", "Kwacha S\u00e0imbitheach (1968\u20132012)" },
            { "zmw", "Kwacha S\u00e0imbitheach" },
            { "zrn", "Za\u00efre \u00f9r Za\u00efreach (1993\u20131998)" },
            { "zrz", "Za\u00efre Za\u00efreach (1971\u20131993)" },
            { "zwd", "Dolar S\u00ecombabuthach (1980\u20132008)" },
            { "zwl", "Dolar S\u00ecombabuthach (2009)" },
            { "zwr", "Dolar S\u00ecombabuthach (2008)" },
        };
        return data;
    }
}
